==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ka_GE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "პირველი გაშვების ოსტატი",
    "Add your profile information! For example your email is needed to reset your password." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მაგალითად, პაროლის აღდგენისთვის საჭიროა თქვენი ელ-ფოსტის მისამართი.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია. დააყენეთ პროფილის ფოტო-სურათი და შეიყვანეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Add your profile information! Set a full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მიუთითეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადსახვა ფუნქციებში.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! დააყენეთ პროფილის ფოტო-სურათი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Get the apps to sync your files" : "თქვენი ფაილების სინქრონიზაციისთვის მოიპოვეთ აპლიკაციები",
    "Desktop client" : "დესკტოპ-კლიენტი",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "Connect your desktop apps to %s" : "დაუკავშირეთ თქვენი დესკტოპ აპლიკაციები %s-ს",
    "Connect your calendar" : "დააკავშირეთ თქვენი კალენდარი",
    "Connect your contacts" : "დააკავშირეთ თქვენი კონტაქტები",
    "Access files via WebDAV" : "დაუკავშირდით ფაილებს WebDAV–ით",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "იქონიეთ წვდომა და თქვენი პირობებით, ნებისმიერი მოწყობილობიდან გააზიარეთ ფაილები, კალენდარი, კონტაქტები, ელ-ფოსტა და სხვა",
    "Connect your Calendar" : "დაუკავშირდით თქვენ კალენდარს",
    "Connect your Contacts" : "დააკავშირეთ თქვენი კონტაქტები",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "მეტი ინფორმაციაა <a target=\"_blank\" href=\"%s\">დოკუმენტაციაში</a> და ჩვენს <a target=\"_blank\" href=\"%s\">ვებ-საიტზე</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "თუ მოგეწონათ Nextcloud-ი, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\">გაუწიეთ მას რეკომენდაცია მეგობრებთან</a> და <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">შეიტანეთ წვლილი მის განვითარებაში</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "თუ გსურთ დაეხმაროთ პროექტს {contributeopen}შეუერთდით დეველოპმენტს{linkclose} ან {contributeopen}გაავრცელეთ სიტყვა{linkclose}!",
    "Show First Run Wizard again" : "პირველი გაშვების ოსტატის ახლიდან ჩვენება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ka_GE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "პირველი გაშვების ოსტატი",
    "Add your profile information! For example your email is needed to reset your password." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მაგალითად, პაროლის აღდგენისთვის საჭიროა თქვენი ელ-ფოსტის მისამართი.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია. დააყენეთ პროფილის ფოტო-სურათი და შეიყვანეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Add your profile information! Set a full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მიუთითეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადსახვა ფუნქციებში.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! დააყენეთ პროფილის ფოტო-სურათი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Get the apps to sync your files" : "თქვენი ფაილების სინქრონიზაციისთვის მოიპოვეთ აპლიკაციები",
    "Desktop client" : "დესკტოპ-კლიენტი",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "Connect your desktop apps to %s" : "დაუკავშირეთ თქვენი დესკტოპ აპლიკაციები %s-ს",
    "Connect your calendar" : "დააკავშირეთ თქვენი კალენდარი",
    "Connect your contacts" : "დააკავშირეთ თქვენი კონტაქტები",
    "Access files via WebDAV" : "დაუკავშირდით ფაილებს WebDAV–ით",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "თუ გსურთ დაეხმაროთ პროექტს {contributeopen}შეუერთდით დეველოპმენტს{linkclose} ან {contributeopen}გაავრცელეთ სიტყვა{linkclose}!",
    "Show First Run Wizard again" : "პირველი გაშვების ოსტატის ახლიდან ჩვენება",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "იქონიეთ წვდომა და თქვენი პირობებით, ნებისმიერი მოწყობილობიდან გააზიარეთ ფაილები, კალენდარი, კონტაქტები, ელ-ფოსტა და სხვა",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "მეტი ინფორმაციაა <a target=\"_blank\" href=\"%s\">დოკუმენტაციაში</a> და ჩვენს <a target=\"_blank\" href=\"%s\">ვებ-საიტზე</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "თუ მოგეწონათ Nextcloud-ი, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\">გაუწიეთ მას რეკომენდაცია მეგობრებთან</a> და <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">შეიტანეთ წვლილი მის განვითარებაში</a>!"
},
"nplurals=2; plural=(n!=1);");
